==> safecheck-3.0.14.jar: safecheck/sqls/QueryCheckPaper.sql <==
SELECT
    *
FROM
    (
        SELECT
            tcp.*,
            f_meter_book_num,
            tud.f_slice_area,
            tud.f_pcd,
            f_aroundmeter,
            f_position,
            f_meternumber,
            f_metertitles,
            tui.f_user_state
        FROM
            (
                SELECT
                    id,
                    f_check_item_id,
                    f_check_plan_id,
                    f_checker_id,
                    f_complete,
                    f_userinfo_code,
                    f_prearranged_date,
                    f_no_checkplan,
                    f_checker_name,
                    f_entry_status,
                    f_usegas,
                    f_state,
                    f_upload_state,
                    f_nongasuser_path,
                    f_noanswer_path,
                    f_rejectcheck_path,
                    f_no_gas_device,
                    f_check_type,
                    f_noncivil_style,
                    f_stop_service,
                    f_usage,
                    f_signname,
                    f_sign_imgid,
                    f_sign_path,
                    f_subcompany,
                    f_user_name,
                    f_user_phone,
                    f_userinfoid,
                    f_card_id,
                    f_area,
                    f_street,
                    f_residential_area,
                    f_building,
                    f_unit,
                    f_floor,
                    f_room,
                    f_address,
                    f_room_style,
                    f_heating_style,
                    f_heating_style_,
                    f_recording1_path,
                    f_recording2_path,
                    f_recording3_path,
                    f_pic1_path,
                    f_pic2_path,
                    f_pic3_path,
                    f_defect_dorm,
                    f_defect_expand,
                    f_defect_other,
                    f_defect_notfixed,
                    f_notfixed_path,
                    f_close_valve,
                    f_close_valve_path,
                    f_unload_battery,
                    f_stop_devices,
                    f_zero_meter,
                    f_cutoff_gas,
                    f_cutoff_gas_path,
                    f_empty_pipe,
                    f_close_adjuster,
                    f_close_adjuster_path,
                    f_defect_notified,
                    f_notified_path,
                    f_defect_registered,
                    f_overall2_path,
                    f_client_suggestion,
                    f_client_evaluation,
                    f_repairman,
                    f_defect_urgency,
                    f_repaired,
                    f_ratification_des,
                    f_repaired_uploaded,
                    f_repair_date,
                    f_amr_path,
                    f_longitude,
                    f_latitude,
                    f_remark,
                    f_approved,
                    f_approved_time,
                    f_approved_by,
                    f_approved_note,
                    f_repair_approved,
                    f_repair_approved_time,
                    f_repair_approved_by,
                    f_repair_approved_note,
                    f_SafeToRepair_id,
                    f_defect_content,
                    f_orgstr,
                    f_filialeids,
                    f_filialeid,
                    f_idnumber,
                    f_plan_id,
                    f_comments,
                    f_userproperties,
                    f_user_inhome_time,
                    f_user_check_time,
                    f_user_spare_phone,
                    f_user_family_remarks,
                    f_user_equipment_remarks,
                    f_collection_type,
                    f_danger_state,
                    f_read_instructions,
                    f_blacklist,
                    f_supplement_tag,
                    f_safecheck_type,
                    f_exceed_reason,
                    f_is_meterreadding,
                    f_blocking_cause,
                    f_send_message,
                    f_laser_check,
                    f_offsite_time,
                     f_onsite_time,
                    f_upload_date
                FROM
                    t_check_paper  WITH ( nolock )
                    where 1=1
                    {
                        f_entry_status != $$ && f_entry_status != null:$and f_entry_status = '{f_entry_status}'$,$$
                    }
            ) tcp
                LEFT JOIN ( SELECT * FROM t_userfiles  WITH ( nolock ) WHERE f_table_state = '正常' ) tbb ON tcp.f_userinfoid= tbb.f_userinfo_id
                LEFT JOIN t_userinfo tui ON tcp.f_userinfoid = tui.f_userinfo_id
                LEFT JOIN t_user_address tud  WITH ( nolock )  ON tcp.f_userinfoid= tud.f_userinfo_id
    ) tt
WHERE
    { condition }
    {
    f_plan_id == $$ :
    $$
    , $
  and f_check_plan_id = '{f_plan_id}'
    $
    }
    {
    f_approved == $$ :
    $$
    , $
  and f_approved = '{f_approved}'
    $
    }
    {
    f_entry_status == $$ :
    $$
    , $
  and f_entry_status = '{f_entry_status}'
    $
    }
    {
    f_no_checkplan == $$ :
    $$
    , $
  and f_no_checkplan = '{f_no_checkplan}'
    $
    }
    {
    f_filialeid == $$ :
    $$
    , $
      and f_filialeid in {f_filialeid}
        $
        }
Order by
    f_offsite_time desc

==> safecheck-3.0.72.jar: safecheck/sqls/QueryCheckPaper.sql <==
SELECT
    *
FROM
    (
        SELECT
            tcp.*,
            tcpi.f_check_version,
            f_meter_book_num,
            tud.f_slice_area,
            tud.f_pcd,
            f_aroundmeter,
            f_position,
            f_meternumber,
            f_metertitles,
            tui.f_user_state,
            tbb.f_gasproperties,
            tbb.f_card_id,
            tbb.f_gas_date,
            tg.f_meter_brand,
            tbb.f_meter_classify,
            tui.f_comments f_user_comm,
            case when cp.f_plan_name is null then '无计划安检' else cp.f_plan_name end f_plan_name
        FROM
            (
                SELECT
                    id,
                    f_check_item_id,
                    f_check_plan_id,
                    f_checker_id,
                    f_complete,
                    f_userinfo_code,
                    f_prearranged_date,
                    f_no_checkplan,
                    f_checker_name,
                    f_entry_status,
                    f_usegas,
                    f_state,
                    f_upload_state,
                    f_nongasuser_path,
                    f_noanswer_path,
                    f_rejectcheck_path,
                    f_no_gas_device,
                    f_check_type,
                    f_noncivil_style,
                    f_stop_service,
                    f_usage,
                    f_signname,
                    f_sign_imgid,
                    f_sign_path,
                    f_subcompany,
                    f_user_name,
                    f_user_phone,
                    f_userinfoid,
                    f_area,
                    f_street,
                    f_residential_area,
                    f_building,
                    f_unit,
                    f_floor,
                    f_room,
                    f_address,
                    f_room_style,
                    f_heating_style,
                    f_heating_style_,
                    f_recording1_path,
                    f_recording2_path,
                    f_recording3_path,
                    f_pic1_path,
                    f_pic2_path,
                    f_pic3_path,
                    f_defect_dorm,
                    f_defect_expand,
                    f_defect_other,
                    f_defect_notfixed,
                    f_notfixed_path,
                    f_close_valve,
                    f_close_valve_path,
                    f_unload_battery,
                    f_stop_devices,
                    f_zero_meter,
                    f_cutoff_gas,
                    f_cutoff_gas_path,
                    f_empty_pipe,
                    f_close_adjuster,
                    f_close_adjuster_path,
                    f_defect_notified,
                    f_notified_path,
                    f_defect_registered,
                    f_overall2_path,
                    f_client_suggestion,
                    f_client_evaluation,
                    f_repairman,
                    f_defect_urgency,
                    f_safe_type,
                    f_repaired,
                    f_ratification_des,
                    f_repaired_uploaded,
                    f_repair_date,
                    f_amr_path,
                    f_longitude,
                    f_latitude,
                    f_remark,
                    f_approved,
                    f_approved_time,
                    f_approved_by,
                    f_approved_note,
                    f_repair_approved,
                    f_repair_approved_time,
                    f_repair_approved_by,
                    f_repair_approved_note,
                    f_SafeToRepair_id,
                    f_defect_content,
                    f_orgstr,
                    f_filialeids,
                    f_filialeid,
                    f_idnumber,
                    f_plan_id,
                    f_comments,
                    f_userproperties,
                    f_user_inhome_time,
                    f_user_check_time,
                    f_user_spare_phone,
                    f_user_family_remarks,
                    f_user_equipment_remarks,
                    f_approvedstart_time,
                    f_collection_type,
                    f_danger_state,
                    f_read_instructions,
                    f_blacklist,
                    f_supplement_tag,
                    f_safecheck_type,
                    f_exceed_reason,
                    f_is_meterreadding,
                    f_blocking_cause,
                    f_send_message,
                    f_laser_check,
                    f_offsite_time,
                    f_onsite_time,
                    f_upload_date
                FROM
                    t_check_paper  WITH ( nolock )
                where 1=1
                    {
                    f_entry_status != $$ && f_entry_status != null:$and f_entry_status = '{f_entry_status}'$,$$
                    }
            ) tcp
                LEFT JOIN ( SELECT * FROM t_userfiles  WITH ( nolock ) WHERE f_table_state = '正常' or f_table_state = '停用' ) tbb ON tcp.f_userinfoid= tbb.f_userinfo_id
                left join t_gasbrand tg on tbb.f_gasbrand_id = tg.id
                left join t_check_plan_item tcpi ON tcp.f_check_item_id = tcpi.id and tcp.f_offsite_time = tcpi.f_last_check_date
                LEFT JOIN t_userinfo tui ON tcp.f_userinfoid = tui.f_userinfo_id
                LEFT JOIN t_user_address tud  WITH ( nolock )  ON tcp.f_userinfoid= tud.f_userinfo_id
                LEFT JOIN t_check_plan cp ON tcp.f_check_plan_id = cp.id
    ) tt
WHERE
    { condition }
    {
    f_plan_id == $$ :
    $$
    , $
  and f_check_plan_id = '{f_plan_id}'
    $
    }
    {
    f_approved == $$ :
    $$
    , $
  and f_approved = '{f_approved}'
    $
    }
    {
    f_no_checkplan == $$ :
    $$
    , $
  and f_no_checkplan = '{f_no_checkplan}'
    $
    }
    {
    f_filialeid == $$ :
    $$
    , $
  and f_filialeid in {f_filialeid}
    $
    }
Order by
    f_offsite_time desc
